
From: Oleg Nesterov <oleg@tv-sign.ru>

del_timer() and __run_timers() use smp_wmb() before clearing timer's pending
flag.  It was needed because __mod_timer() did not locked old_base if the
timer is not pending, so __mod_timer()->internal_add_timer() can race with
del_timer()->list_del().

With the previous patch these functions are serialized through base->lock, so
the barrier can be killed.

Still needed in del_timer_sync(), because it clears ->_base.

Signed-off-by: Oleg Nesterov <oleg@tv-sign.ru>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/kernel/timer.c |    3 ---
 1 files changed, 3 deletions(-)

diff -puN kernel/timer.c~timers-remove-memory-barriers kernel/timer.c
--- 25/kernel/timer.c~timers-remove-memory-barriers	2005-03-19 14:19:57.000000000 -0800
+++ 25-akpm/kernel/timer.c	2005-03-19 14:19:57.000000000 -0800
@@ -337,8 +337,6 @@ repeat:
 		goto repeat;
 	}
 	list_del(&timer->entry);
-	/* Need to make sure that anybody who sees a NULL base also sees the list ops */
-	smp_wmb();
 	__set_base(timer, base, 0);
 	spin_unlock_irqrestore(&base->lock, flags);
 
@@ -496,7 +494,6 @@ repeat:
 
 			list_del(&timer->entry);
 			set_running_timer(base, timer);
-			smp_wmb();
 			__set_base(timer, base, 0);
 			spin_unlock_irq(&base->lock);
 			{
_
